(* x)(* x y)(* x y & more)(+ x)(+ x y)(+ x y & more)(- x)(- x y)(- x y & more)(/ x)(/ x y)(/ x y & more)(< _)(< x y)(< x y & more)(<= _)(<= x y)(<= x y & more)(> _)(> x y)(> x y & more)(>= _)(>= x y)(>= x y & more)(boxed f x)Transform the quantity's number by any fn (i.e. fmap on the quantity-functor). Also works for numbers.
Transform the quantity's number by any fn (i.e. fmap on the quantity-functor). Also works for numbers.
(defunit unit-fn-name measure symb scale-or-comp)(defunit unit-fn-name measure symb scaling composition)(from-edn x)(max x)(max x y)(max x y & more)(measure u)What this quantity is a measure of.
What this quantity is a measure of.
(min x)(min x y)(min x y & more)(new-unit measure symb scale-or-comp)(new-unit measure symb scaling composition)Register a new type of unit with the given measure, symbol, composition and/or scaling. Returns a fn (fn [number]) that creates a quantity of this unit.
Register a new type of unit with the given measure, symbol, composition and/or scaling. Returns a fn (fn [number]) that creates a quantity of this unit.
(num u)Get the number from a quantity. Pass through if already a number.
Get the number from a quantity. Pass through if already a number.
(symbol u)The unit symbol for this quantity.
The unit symbol for this quantity.
(to-edn u)(with-num unit n)Make copy of a quantity with a different number.
Make copy of a quantity with a different number.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |